@@ -24,7 +24,7 @@ class LogstashClient(NamespacedClient):
         """
         Deletes Logstash Pipelines used by Central Management
 
-        `<https://www.elastic.co/guide/en/elasticsearch/reference/7.x/logstash-api-delete-pipeline.html>`_
+        `<https://www.elastic.co/guide/en/elasticsearch/reference/7.14/logstash-api-delete-pipeline.html>`_
 
         :arg id: The ID of the Pipeline
         """
@@ -43,7 +43,7 @@ class LogstashClient(NamespacedClient):
         """
         Retrieves Logstash Pipelines used by Central Management
 
-        `<https://www.elastic.co/guide/en/elasticsearch/reference/7.x/logstash-api-get-pipeline.html>`_
+        `<https://www.elastic.co/guide/en/elasticsearch/reference/7.14/logstash-api-get-pipeline.html>`_
 
         :arg id: A comma-separated list of Pipeline IDs
         """
@@ -62,7 +62,7 @@ class LogstashClient(NamespacedClient):
         """
         Adds and updates Logstash Pipelines used for Central Management
 
-        `<https://www.elastic.co/guide/en/elasticsearch/reference/7.x/logstash-api-put-pipeline.html>`_
+        `<https://www.elastic.co/guide/en/elasticsearch/reference/7.14/logstash-api-put-pipeline.html>`_
 
         :arg id: The ID of the Pipeline
         :arg body: The Pipeline to add or update
